@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '2.6.3';
+$Git::Hooks::CheckJira::VERSION = '2.7.0';
 use 5.010;
 use utf8;
 use strict;
@@ -67,11 +67,12 @@ sub _jira {
     # Connect to JIRA if not yet connected
     unless (exists $cache->{jira}) {
         unless (eval { require JIRA::REST; }) {
-            $git->fault(<<"EOS", {details => $@});
+            $git->fault(<<EOS, {details => $@});
 I could not load the JIRA::REST Perl module.
 
-I need it to talk to your JIRA server, as configured by the $CFG.* options in
-your Git configuration.
+I need it to talk to your JIRA server, as configured by the
+$CFG.jiraurl, $CFG.jirauser, and $CFG.jirapass
+options in your Git configuration.
 
 Please, install the module or disable these options to proceed.
 EOS
@@ -81,8 +82,8 @@ EOS
         my %jira;
         for my $option (qw/jiraurl jirauser jirapass/) {
             $jira{$option} = $git->get_config($CFG => $option)
-                or $git->fault(<<"EOS")
-The $CFG.$option option is missing from the configuration.
+                or $git->fault(<<EOS, {option => $option})
+The option is missing from the configuration.
 It's required in order to connect to the JIRA server.
 EOS
                 and return;
@@ -91,7 +92,7 @@ EOS
 
         my $jira = eval { JIRA::REST->new($jira{jiraurl}, $jira{jirauser}, $jira{jirapass}) };
         length $@
-            and $git->fault(<<"EOS", {details => $@})
+            and $git->fault(<<EOS, {details => $@})
 Cannot connect to the JIRA server at '$jira{jiraurl}' as '$jira{jirauser}.
 
 Please, check your $CFG.jiraurl, $CFG.jirauser,
@@ -145,22 +146,27 @@ sub check_codes {
                 $code = do $check;
                 unless ($code) {
                     if (length $@) {
-                        $git->fault("I couldn't parse $CFG.check-code option ($check).", {details => $@});
+                        $git->fault("I couldn't parse option value ($check).",
+                                    {option => 'check-code', details => $@});
                     } elsif (! defined $code) {
-                        $git->fault("I couldn't do $CFG.check-code option ($check).", {details => $!});
+                        $git->fault("I couldn't do option value ($check).",
+                                    {option => 'check-code', details => $!});
                     } else {
-                        $git->fault("I couldn't run $CFG.check-code option ($check).");
+                        $git->fault("I couldn't run  option value ($check).",
+                                    {option => 'check-code'});
                     }
                     next CODE;
                 }
             } else {
                 $code = eval $check; ## no critic (BuiltinFunctions::ProhibitStringyEval)
                 length $@
-                    and $git->fault("I couldn't parse $CFG.check-code option value.", {details => $@})
+                    and $git->fault("I couldn't parse option value.",
+                                    {option => 'check-code', details => $@})
                     and next CODE;
             }
             defined $code and ref $code and ref $code eq 'CODE'
-                or $git->fault("The $CFG.check-code option must end with a code-ref.")
+                or $git->fault("The option value must end with a code-ref.",
+                               {option => 'check-code'})
                 and next CODE;
             push @{$cache->{codes}}, $code;
         }
@@ -174,8 +180,8 @@ sub _check_jira_keys {          ## no critic (ProhibitExcessComplexity)
 
     unless (@keys) {
         if ($git->get_config_boolean($CFG => 'require')) {
-            $git->fault(<<"EOS");
-The commit @{[$commit->commit]} must cite a JIRA in its message.
+            $git->fault(<<EOS, {commit => $commit});
+The commit must cite a JIRA in its message.
 
 Please, amend your commit to insert a JIRA key.
 EOS
@@ -235,8 +241,8 @@ EOS
 
         if (my $missed_set = $cited_set - $matched_set) {
             if ($missed_set->size == 1) {
-                $git->fault(<<"EOS");
-The commit @{[$commit->commit]} cites an invalid issue:
+                $git->fault(<<EOS, {commit => $commit});
+The commit cites an invalid issue:
 
   @{[$missed_set]}
 
@@ -247,8 +253,8 @@ The issue does not match the following JQL expression:
 Please, update your issue or fix your $CFG git configuration.
 EOS
             } else {
-                $git->fault(<<"EOS");
-The commit @{[$commit->commit]} cites invalid issues:
+                $git->fault(<<EOS, {commit => $commit});
+The commit cites invalid issues:
 
   @{[$missed_set]}
 
@@ -290,11 +296,10 @@ EOS
       ISSUE:
         while (my ($key, $issue) = each %issues) {
             if ($unresolved && defined $issue->{fields}{resolution}) {
-                $git->fault(<<"EOS");
-The commit @{[$commit->commit]} cites issue $key which is already resolved.
+                $git->fault(<<EOS, {commit => $commit, option => 'unresolved'});
+The commit cites issue $key which is already resolved.
 
-The $CFG.unresolved option in your configuration requires
-that all JIRA issues be unresolved.
+The option in your configuration requires that all JIRA issues be unresolved.
 EOS
                 ++$errors;
                 next ISSUE;
@@ -309,11 +314,11 @@ EOS
                         next VERSION if $fixversion->{name} eq $version;
                     }
                 }
-                $git->fault(<<"EOS");
-The commit @{[$commit->commit]} cites issue $key which is invalid.
+                $git->fault(<<EOS, {commit => $commit, option => 'fixversion'});
+The commit cites issue $key which is invalid.
 
 Commits on '$ref' must cite issues associated with a fixVersion matching
-'$version' according to the $CFG.fixversion options in your configuration.
+'$version' according to the configuration option.
 EOS
                 ++$errors;
                 next ISSUE;
@@ -321,7 +326,7 @@ EOS
 
             if ($by_assignee) {
                 my $user = $git->authenticated_user()
-                    or $git->fault(<<"EOS")
+                    or $git->fault(<<EOS)
 Internal error: I cannot get your username to authorize you.
 Please check your Git::Hooks configuration with regards to the function
 https://metacpan.org/pod/Git::Repository::Plugin::GitHooks#authenticated_user
@@ -332,19 +337,17 @@ EOS
                 if (my $assignee = $issue->{fields}{assignee}) {
                     my $name = $assignee->{name};
                     $user eq $name
-                        or $git->fault(<<"EOS")
-The commit @{[$commit->commit]} cites issue $key which is assigned to '$name'.
-The $CFG.by-assignee configuration requires that cited issues be assigned
-to you ($user).
+                        or $git->fault(<<EOS, {commit => $commit, option => 'by-assignee'})
+The commit cites issue $key which is assigned to '$name'.
+The option requires that cited issues be assigned to you ($user).
 Please, update your issue.
 EOS
                         and ++$errors
                         and next KEY;
                 } else {
-                    $git->fault(<<"EOS");
-The commit @{[$commit->commit]} cites issue $key which is unassigned.
-The $CFG.by-assignee configuration requires that cited issues be assigned
-to you ($user).
+                    $git->fault(<<EOS, {commit => $commit, option => 'by-assignee'});
+The commit cites issue $key which is unassigned.
+The option requires that cited issues be assigned to you ($user).
 Please, update your issue.
 EOS
                     ++$errors;
@@ -363,7 +366,8 @@ EOS
             if (defined $ok) {
                 ++$errors unless $ok;
             } elsif (length $@) {
-                $git->fault('Error while evaluating $CFG.check-code', {details => $@});
+                $git->fault('Error while evaluating option value.',
+                            {option => 'check-code', details => $@});
                 ++$errors;
             }
         } else {
@@ -497,13 +501,13 @@ sub notify_commit_msg {
     my $show = $git->run(show => '--stat', $commit->commit);
 
     my %comment = (
-        body => <<"EOF",
+        body => <<EOS,
 [$PKG] commit refers to this issue:
 
 {noformat}
 $show
 {noformat}
-EOF
+EOS
     );
     $comment{visibility} = $visibility if $visibility;
 
@@ -511,7 +515,8 @@ EOF
 
     foreach my $key (@keys) {
         eval { $jira->POST("/issue/$key/comment", undef, \%comment); 1; }
-            or $git->fault("I could not add a comment to JIRA issue $key.", {details => $@})
+            or $git->fault("I could not add a comment to JIRA issue $key.",
+                           {commit => $commit, details => $@})
             and ++$errors;
     }
 
@@ -554,10 +559,10 @@ sub notify_affected_refs {
             value => $2,
         };
     } elsif ($comment ne 'all') {
-        $git->fault(<<"EOS");
+        $git->fault(<<EOS, {option => $comment});
 Configuration error.
 
-The $CFG.comment option is defined as '$comment', but
+The option is defined as '$comment', but
 the valid values are 'role:ROLE', 'group:GROUP', or 'all'.
 Please, check your git configuration.
 EOS
@@ -600,7 +605,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 2.6.3
+version 2.7.0
 
 =head1 SYNOPSIS
 
